/*
 * jDigiClock plugin 3.0.1 - Modification pour utilisation de rpcache-aa.meteofrance.com le 03/04/2021 (et sans proxy)
 *
 * http://www.radoslavdimov.com/jquery-plugins/jquery-plugin-digiclock/
 *
 * Copyright (c) 2009 Radoslav Dimov
 *
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 * 17-NOV-2013:  2.1.1 Modified by Andrew Mercer to use offset from Server Time. Allows display of other timezones.
 * 08-FEB-2015:  2.1.2 Adapted to use Yahoo weather (AccuWeather not working) and JSONP (No proxy)
 * 21-MAR-2015:  2.1.3 Added .promise().done(function () {}) reference for compatibility with later jquery versions
 *                     Avoids repeated sliding panels on left/right clicks. Based on update by s4ty at
 *                     http://www.jquery-board.de/threads/3458-jDigiClock/page4
 *                     Doc here : http://www.baldwhiteguy.co.nz/jdigiclock/
 * 31-MAY-2016:  2.1.4 Adapted to have only 1 single view page, added French language
 * 13-JAN-2017:  2.1.5 Fixed Yahoo API connection issues 
 * 5-JAN-2019:   3.0.0 Migrated to undocumented MeteoFrance API
 * 7-AUG-2020:   3.0.1 Change of API for sunrise / sunset
 *                
 *
 * Dual licensed under the MIT and GPL licenses:
 * http://www.opensource.org/licenses/mit-license.php
 * http://www.gnu.org/licenses/gpl.html
 *
 
 */


// Proxy Google App. Cf. http://www.ajax-cross-origin.com
//proxyGoogleCrossOrigin = "https://script.google.com/macros/s/XXXXXXXXX";
//proxyGoogleCrossOrigin = "./script/proxy.php";

//Tableau des prévisions Météo
var previs ="";

(function($) {
    $.fn.extend({

        jdigiclock: function(options) {

            var defaults = {
                imagesPath: '/dashboard/jdigiclock/images/',
                lang: 'fr',
                am_pm: false,
                weatherLocationCode: '', // Meteofrance city code
                lat: '',
                lon: "",
                //SolarCalendarLocationCode: 'lat=48.887489&lng=2.32213&formatted=0',
                weatherUpdate: 59,
                svrOffset: 0   
            };

            var regional = [];
            regional['fr'] = {
                monthNames: ['Jan', 'Fév', 'Mar', 'Avr', 'Mai', 'Juin', 'Juil', 'Août', 'Sept', 'Oct', 'Nov', 'Déc'],
                dayNames: ['Dim', 'Lun', 'Mar', 'Mer', 'Jeu', 'Ven', 'Sam'],
                lang: 'fr'
            }
            regional['en'] = {
                monthNames: ['Jan', 'Feb', 'Mar', 'Apr', 'May', 'Jun', 'Jul', 'Aug', 'Sep', 'Oct', 'Nov', 'Dec'],
                dayNames: ['Sun', 'Mon', 'Tue', 'Wed', 'Thu', 'Fri', 'Sat'],
                lang: 'en'
            }


            var options = $.extend(defaults, options);

            return this.each(function() {
                
                var $this = $(this);
                var o = options;
                $this.imagesPath = o.imagesPath;
                $this.lang = regional[o.lang] == undefined ? regional['en'] : regional[o.lang];
                $this.am_pm = o.am_pm;
                $this.weatherLocationCode = o.weatherLocationCode;
                $this.lat = o.lat;
                $this.lon = o.lon;
                //$this.SolarCalendarLocationCode = o.SolarCalendarLocationCode;
                $this.weatherUpdate = o.weatherUpdate;
                $this.svrOffset = o.svrOffset;
                $this.clockImagesPath = o.imagesPath + 'clock/';
                $this.weatherImagesPath = o.imagesPath + 'pictosvg/';
                $this.currDate = '';
                $this.timeUpdate = '';


                var html = '<div id="plugin_container">';
                html    += '<div id="clock"></div>';
                html    += '<div id="weather"></div>';                
                html    += '<div id="detail" style="display: none;">coucou</div>';
                html    += '</div>';

                $this.html(html);
                
                $('#detail').click(function() {
                		$('#detail').toggle("slide");
                		$this.find('#plugin_container').css('background','url('
                			+ $this.imagesPath
                			+ 'background.png) 50% 25px no-repeat');
                		$('#weather').toggle("slide");
                });
                

                $this.find('#weather').html('<p class="loading">Update Weather ...<br><span style="font-size:16px;"><img src="' + $this.imagesPath + 'refresh_grey.png" alt="reload" title="reload" id="reload" /> Reload</span></p>');

                $this.displayClock($this);

                $this.displayWeather($this);               

            });
        }
    });
   



    $.fn.displayClock = function(el) {
        $.fn.getTime(el);
        setTimeout(function() {$.fn.displayClock(el)}, $.fn.delay());
    }

    $.fn.displayWeather = function(el) {
    	$.fn.getWeather(el);
        if (el.weatherUpdate > 0) {
            setTimeout(function() {$.fn.displayWeather(el)}, (el.weatherUpdate * 60 * 1000));
        }
    }

    $.fn.delay = function() {
        var now = new Date();
        var delay = (60 - now.getSeconds()) * 1000;
        
        return delay;
    }

    $.fn.getTime = function(el) {
        var localtime = new Date();
        var now = new Date(localtime.getTime() - el.svrOffset);
        var old = new Date();
        old.setTime(now.getTime() - 60000);
        
        var now_hours, now_minutes, old_hours, old_minutes, timeOld = '';
        now_hours =  now.getHours();
        now_minutes = now.getMinutes();
        old_hours =  old.getHours();
        old_minutes = old.getMinutes();

        if (el.am_pm) {
            var am_pm = now_hours > 11 ? 'pm' : 'am';
            now_hours = ((now_hours > 12) ? now_hours - 12 : now_hours);
            old_hours = ((old_hours > 12) ? old_hours - 12 : old_hours);
        } 

        now_hours   = ((now_hours <  10) ? "0" : "") + now_hours;
        now_minutes = ((now_minutes <  10) ? "0" : "") + now_minutes;
        old_hours   = ((old_hours <  10) ? "0" : "") + old_hours;
        old_minutes = ((old_minutes <  10) ? "0" : "") + old_minutes;
        // date
        el.currDate = el.lang.dayNames[now.getDay()] + '&nbsp;' + now.getDate() + '&nbsp;' + el.lang.monthNames[now.getMonth()];
        // time update
        el.timeUpdate = now_hours + ':' + now_minutes;

        var firstHourDigit = old_hours.substr(0,1);
        var secondHourDigit = old_hours.substr(1,1);
        var firstMinuteDigit = old_minutes.substr(0,1);
        var secondMinuteDigit = old_minutes.substr(1,1);
        
        timeOld += '<div id="hours"><div class="line"></div>';
        timeOld += '<div id="hours_bg"><img src="' + el.clockImagesPath + 'clockbg1.png" /></div>';
        timeOld += '<img src="' + el.clockImagesPath + firstHourDigit + '.png" id="fhd" class="first_digit" />';
        timeOld += '<img src="' + el.clockImagesPath + secondHourDigit + '.png" id="shd" class="second_digit" />';
        timeOld += '</div>';
        timeOld += '<div id="minutes"><div class="line"></div>';
        if (el.am_pm) {
            timeOld += '<div id="am_pm"><img src="' + el.clockImagesPath + am_pm + '.png" /></div>';
        }
        timeOld += '<div id="minutes_bg"><img src="' + el.clockImagesPath + 'clockbg1.png" /></div>';
        timeOld += '<img src="' + el.clockImagesPath + firstMinuteDigit + '.png" id="fmd" class="first_digit" />';
        timeOld += '<img src="' + el.clockImagesPath + secondMinuteDigit + '.png" id="smd" class="second_digit" />';
        timeOld += '</div>';

        el.find('#clock').html(timeOld);

        // set minutes
        if (secondMinuteDigit != '9') {
            firstMinuteDigit = firstMinuteDigit + '1';
        }

        if (old_minutes == '59') {
            firstMinuteDigit = '511';
        }

        setTimeout(function() {
            $('#fmd').attr('src', el.clockImagesPath + firstMinuteDigit + '-1.png');
            $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg2.png');
        },200);
        setTimeout(function() { $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg3.png')},250);
        setTimeout(function() {
            $('#fmd').attr('src', el.clockImagesPath + firstMinuteDigit + '-2.png');
            $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg4.png');
        },400);
        setTimeout(function() { $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg5.png')},450);
        setTimeout(function() {
            $('#fmd').attr('src', el.clockImagesPath + firstMinuteDigit + '-3.png');
            $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg6.png');
        },600);

        setTimeout(function() {
            $('#smd').attr('src', el.clockImagesPath + secondMinuteDigit + '-1.png');
            $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg2.png');
        },200);
        setTimeout(function() { $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg3.png')},250);
        setTimeout(function() {
            $('#smd').attr('src', el.clockImagesPath + secondMinuteDigit + '-2.png');
            $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg4.png');
        },400);
        setTimeout(function() { $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg5.png')},450);
        setTimeout(function() {
            $('#smd').attr('src', el.clockImagesPath + secondMinuteDigit + '-3.png');
            $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg6.png');
        },600);

        setTimeout(function() {$('#fmd').attr('src', el.clockImagesPath + now_minutes.substr(0,1) + '.png')},800);
        setTimeout(function() {$('#smd').attr('src', el.clockImagesPath + now_minutes.substr(1,1) + '.png')},800);
        setTimeout(function() { $('#minutes_bg img').attr('src', el.clockImagesPath + 'clockbg1.png')},850);

        // set hours
        if (now_minutes == '00') {
           
            if (el.am_pm) {
                if (now_hours == '00') {                   
                    firstHourDigit = firstHourDigit + '1';
                    now_hours = '12';
                } else if (now_hours == '01') {
                    firstHourDigit = '001';
                    secondHourDigit = '111';
                } else {
                    firstHourDigit = firstHourDigit + '1';
                }
            } else {
                if (now_hours != '10') {
                    firstHourDigit = firstHourDigit + '1';
                }

                if (now_hours == '20') {
                    firstHourDigit = '1';
                }

                if (now_hours == '00') {
                    firstHourDigit = firstHourDigit + '1';
                    secondHourDigit = secondHourDigit + '11';
                }
            }

            setTimeout(function() {
                $('#fhd').attr('src', el.clockImagesPath + firstHourDigit + '-1.png');
                $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg2.png');
            },200);
            setTimeout(function() { $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg3.png')},250);
            setTimeout(function() {
                $('#fhd').attr('src', el.clockImagesPath + firstHourDigit + '-2.png');
                $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg4.png');
            },400);
            setTimeout(function() { $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg5.png')},450);
            setTimeout(function() {
                $('#fhd').attr('src', el.clockImagesPath + firstHourDigit + '-3.png');
                $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg6.png');
            },600);

            setTimeout(function() {
            $('#shd').attr('src', el.clockImagesPath + secondHourDigit + '-1.png');
            $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg2.png');
            },200);
            setTimeout(function() { $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg3.png')},250);
            setTimeout(function() {
                $('#shd').attr('src', el.clockImagesPath + secondHourDigit + '-2.png');
                $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg4.png');
            },400);
            setTimeout(function() { $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg5.png')},450);
            setTimeout(function() {
                $('#shd').attr('src', el.clockImagesPath + secondHourDigit + '-3.png');
                $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg6.png');
            },600);

            setTimeout(function() {$('#fhd').attr('src', el.clockImagesPath + now_hours.substr(0,1) + '.png')},800);
            setTimeout(function() {$('#shd').attr('src', el.clockImagesPath + now_hours.substr(1,1) + '.png')},800);
            setTimeout(function() { $('#hours_bg img').attr('src', el.clockImagesPath + 'clockbg1.png')},850);
        }
    } //fin fn.getTime

$.fn.getWeather = function(el) {
	var urlmeteo='https://rpcache-aa.meteofrance.com/internet2018client/2.0/forecast?lat='+el.lat+'&lon='+el.lon+'&id='+ el.weatherLocationCode + '&instants=morning,afternoon,evening,night&day=5&token=__Wj7dVSTjV9YGu1guveLyDq0g7S7TfTjaHBTPTpO0kj8__';
	var urlmeteo2='https://rpcache-aa.meteofrance.com/internet2018client/2.0/observation/gridded?lat='+el.lat+'&lon='+el.lon+'&token=__Wj7dVSTjV9YGu1guveLyDq0g7S7TfTjaHBTPTpO0kj8__';
	
	previs=[];
	//On récupère la météo du moment
	$.getJSON(urlmeteo2
		, function (data) {
		if (typeof data !== 'undefined' && data != null) {
			previs['now'] =[];
			previs['now']['griddedtime']=new Date(data.properties.gridded.time);
			previs['now']['T']=data.properties.gridded.T;
			previs['now']['windspeed']=Math.ceil(3.6*data.properties.gridded.wind_speed/5)*5;
			previs['now']['icon']=data.properties.gridded.weather_icon;
			previs['now']['weather_description']=data.properties.gridded.weather_description;
			
			
			// On récupère les prévisions sur 5 jours
			$.getJSON(urlmeteo
				, function (data) {
			if (typeof data !== 'undefined' && data != null) {
				previs['name']=data.properties.name;
				//previs['now'] =[];
				//previs['now']['T']=data.properties.forecast[0].T;//A modifier
				//previs['now']['moment']=data.properties.forecast[0].moment_day;
				//previs['now']['windspeed']=Math.ceil(3.6*data.properties.forecast[0].wind_speed/5)*5;
				
				
				//Recherche du jour en cours dans les prévis :
				var temp_now_utc = new Date();
                temp_now_utc = temp_now_utc.toISOString().substring(0, 10); // UTC
                var num = 0;
                while (num + 1 < data.properties.daily_forecast.length) {
                    var forecast_time = data.properties.daily_forecast[num].time.substring(0, 10);
                    if (forecast_time >= temp_now_utc)
                        break;
                    num=num+1;
                }
				previs['now']['date']= new Date(data.properties.daily_forecast[num].time);
				//ephemeride du jour
				previs['now']['sunrise_time']=data.properties.daily_forecast[num].sunrise_time;
				previs['now']['sunset_time']=data.properties.daily_forecast[num].sunset_time;
				
				//On affecte les prévisions journalières sur 5 jours (à partir du num)
				for (i = 0; i <= 4; i++) {
					previs[i+"day"]=[];
					previs[i+"day"]["date"] = new Date(data.properties.daily_forecast[num+i].time);
					previs[i+"day"]["icon"] = data.properties.daily_forecast[num+i].daily_weather_icon;
					previs[i+"day"]["weather_description"] = data.properties.daily_forecast[num+i].daily_weather_description;
					previs[i+"day"]["T_min"] = Math.round(data.properties.daily_forecast[num+i].T_min);
					previs[i+"day"]["T_max"] = Math.round(data.properties.daily_forecast[num+i].T_max);
					previs[i+"day"]["total_precipitation_24h"] = data.properties.daily_forecast[num+i].total_precipitation_24h;
				}
				
				
				//affecte les prévisions par moment de la journée sur les 5 jours
				var theday = new Date(data.properties.forecast[0].time).toISOString().substring(0, 10);
				var i = 0;
				var ind= 0;
				previs[i+"day"]['day']=[];
				
				var index = 0;
                while (index + 1 < data.properties.forecast.length) {
                    if(theday!=data.properties.forecast[index].time.substring(0, 10)) {
                    	i=i+1;
                    	if(i>=5) break;
                    	previs[i+"day"]['day']=[];
                    	theday=data.properties.forecast[index].time.substring(0, 10);
                    	
                    	
                    }
                    switch (data.properties.forecast[index].moment_day) {
							case 'nuit':
								ind =0;
								break;
							case 'matin':
								ind =1;
								break;
							case 'après-midi':
								ind =2;
								break;
							case 'soirée':
								ind =3;
								break;
					}
					previs[i+"day"]['day'][ind]=[];
					previs[i+"day"]['day'][ind]['time']= new Date(data.properties.forecast[index].time);
					previs[i+"day"]['day'][ind]['moment_day']= data.properties.forecast[index].moment_day;
					previs[i+"day"]['day'][ind]['T']= data.properties.forecast[index].T;
					previs[i+"day"]['day'][ind]['T_windchill']= data.properties.forecast[index].T_windchill;
					previs[i+"day"]['day'][ind]['wind_speed']= Math.ceil(3.6*data.properties.forecast[index].wind_speed/5)*5;
					previs[i+"day"]['day'][ind]['wind_speed_gust']= Math.ceil(3.6*data.properties.forecast[index].wind_speed_gust/5)*5;
					previs[i+"day"]['day'][ind]['icon']= data.properties.forecast[index].weather_icon;
					previs[i+"day"]['day'][ind]['weather_description']= data.properties.forecast[index].weather_description;
					previs[i+"day"]['day'][ind]['rain_hazard_6h']= data.properties.probability_forecast[index].rain_hazard_6h;
					previs[i+"day"]['day'][ind]['freezing_hazard']= data.properties.probability_forecast[index].freezing_hazard;
					previs[i+"day"]['day'][ind]['snow_hazard_6h']= data.properties.probability_forecast[index].snow_hazard_6h;
					previs[i+"day"]['day'][ind]['storm_hazard']= data.properties.probability_forecast[index].storm_hazard;
                    
					index=index+1;
                }
				$.fn.ShowWeather(el);
  	  	  	} else { // Si pb de connexion à l'API
                // On change la couleur du bouton refresh en rouge
                $('#reload').attr('src', el.imagesPath + 'refresh_red.png');  
            }

  	  	});
  	  		
  	  		} else { // Si pb de connexion à l'API
                // On change la couleur du bouton refresh en rouge
                $('#reload').attr('src', el.imagesPath + 'refresh_red.png');  
            }

  	  	});
} //fin getWeather
  	  
 $.fn.ShowWeather = function(el) {
 	 console.log(previs);
 	
 	var curr_temp = '<p class="temp">' + previs['now']['T']
 	 	+ '&deg;<span class="metric">'
 	 	+ 'C' + '</span></p>';
 	 

    var journow = previs['now']['date'];
    el.find('#weather').css('background','url('
                         + el.weatherImagesPath 
                         + previs["0day"]['icon']   // 1er élèment du forecast journalier
                         + '.svg) no-repeat center/60%');
                                                        
   var weather = '<div id="Oday" style="height:120px"><div id="local"><p class="city">' 
                             + previs['name']
                             + '</p>' 
                             + '<p class="high_low">' 
                              + previs["0day"]['T_min']
                              + '&deg;&nbsp;/&nbsp;' 
                              + previs["0day"]['T_max']
                              + '&deg;</p>';
  if(previs["0day"]['total_precipitation_24h']!="0") weather += '<p class="rain">💧&nbsp;'
                              + previs["0day"]['total_precipitation_24h'] + '&nbsp;mm'
                              + '</p>';
                              
  weather +='</div>';

   weather += '<div id="temp"><p id="date">' 
                         + el.lang.dayNames[journow.getDay()] + '&nbsp;' + journow.getDate() + '&nbsp;' + el.lang.monthNames[journow.getMonth()]
                         + '</p>' 
                         + curr_temp
                         +'<p class="rain"><font color="white">💨</font>&nbsp;'
                              + previs['now']['windspeed'] + '&nbsp;km/h'
                              + '</p>'
                         + '</div>'
                         + '<img class="imgnow" src="' 
                                  + el.weatherImagesPath 
                                  + previs["now"]["icon"]
                                  + '.svg" alt="' 
                                  + previs["now"]["weather_description"]
                                  + '" title="' 
                                  + previs["now"]["weather_description"]
                                  + '" />';
                         +'</div>';
                         //+ '&nbsp;' +previs['now']['moment']

  el.find('#weather').html(weather);
  el.find('#weather').append('<div id="forecast"></div>');                
  for (i = 1; i <= 4; i++) {
  	  //d_day_code = String(i) + '_resume';
  	  var d_date = previs[i+"day"]["date"];
  	  var forecast = '<div id="'+i+'day">';
  	  forecast    += '<p class="dayname">' + el.lang.dayNames[d_date.getDay()] + '&nbsp;' + d_date.getDate() + '</p>'
                                  + '<img src="' 
                                  + el.weatherImagesPath 
                                  + previs[i+"day"]["icon"]
                                  + '.svg" alt="' 
                                  + previs[i+"day"]["weather_description"]
                                  + '" title="' 
                                  + previs[i+"day"]["weather_description"]
                                  + '" />';
                               
       forecast    += '<div class="daytemp">' 
                                  + previs[i+"day"]["T_min"]
                                  + '&deg;&nbsp;/&nbsp;' 
                                  + previs[i+"day"]["T_max"]
                                  + '&deg;';
                                  
       if(previs[i+"day"]["total_precipitation_24h"]!=0) forecast    += '<p class="raintemp">💧&nbsp;'+previs[i+"day"]["total_precipitation_24h"] +'&nbsp;mm</p>';
       forecast    += '</div>';                        
       forecast    += '</div>';
       el.find('#forecast').append(forecast);
  }
  
  el.find('#weather').append('<div id="bottom"><div id="soleil"></div><div id="update"><img src="' + el.imagesPath + 'refresh_grey.png" alt="reload" title="reload" id="reload" />' + el.timeUpdate + '</div></div>');
  
  sunrise = new Date(previs['now']['sunrise_time']);
  sunrise_formatted = sunrise.getHours() + "h" + (sunrise.getMinutes()<10?'0':'') + sunrise.getMinutes();
  sunset = new Date(previs['now']['sunset_time']);
  sunset_formatted = sunset.getHours() + "h" + (sunset.getMinutes()<10?'0':'') + sunset.getMinutes();
  soleil = '<font color="yellow">☀</font> ▲&nbsp;' + sunrise_formatted + '&nbsp;&nbsp;&nbsp;▼&nbsp;' + sunset_formatted;
  el.find('#soleil').append(soleil);
  
  $('#reload').click(function() {
  		  console.log('reload');
  		  $.fn.getWeather(el);
  });
  $('#Oday').click(function() {
                		$.fn.showdetail(el, '0day');
                });
  $('#1day').click(function() {
                		$.fn.showdetail(el, '1day');
                });
  $('#2day').click(function() {
                		$.fn.showdetail(el, '2day');
                });
  $('#3day').click(function() {
                		$.fn.showdetail(el, '3day');
                });
  $('#4day').click(function() {
                		$.fn.showdetail(el, '4day');
                });
  
 } //fin showWeather


 

$.fn.showdetail = function(el, day) {
	var previ=previs[day]["day"];
	var journow=previs[day]["date"];
	var detailday='<p class="datedetail">'+el.lang.dayNames[journow.getDay()] + '&nbsp;' + journow.getDate() + '&nbsp;' + el.lang.monthNames[journow.getMonth()]+'</p>';
	for(var i= 0; i < previ.length; i++) {
		if(previ[i]) {
		detailday+='<div>'
			+'<p class="dayname">'+previ[i]["moment_day"] + '</p>'
			+'<img src="' 
                   + el.weatherImagesPath 
                   + previ[i]["icon"]
                   + '.svg" alt="'
                   + previ[i]["weather_description"]
                   + '" title="'
                   + previ[i]["weather_description"]
             + '" />'
             +'<p>'+previ[i]["T"]
                    + '&deg;C</p>'
             +'<p class="daytemp">'+ 'Ressentie:</br>'+previ[i]["T_windchill"]+'&deg;C'+'</p>'
             +'<p class="hazard">'+ '<font color="white">💨</font>&nbsp;'+previ[i]["wind_speed"]+"km/h"
      if(previ[i]["wind_speed_gust"]>0) detailday+='&nbsp;<mark>'+previ[i]["wind_speed_gust"]+"</mark>"
             
             detailday+='</p>';
 		
		detailday+='<p class="hazard">';
             if(previ[i]["rain_hazard_6h"]!=null&&previ[i]["rain_hazard_6h"]!="0") {
             	 detailday+='💧&nbsp;'+previ[i]["rain_hazard_6h"]+'%';
             }
             if(previ[i]["snow_hazard_6h"]!=null&&previ[i]["snow_hazard_6h"]!="0") {
             	 detailday+=' ❅&nbsp;'+previ[i]["snow_hazard_6h"]+'%';
             }
             if(previ[i]["freezing_hazard"]!=null&&previ[i]["freezing_hazard"]!="0") {
             	 detailday+='</br><img style="width:8px;" src="' + el.imagesPath + 'cold.svg" />&nbsp;'+previ[i]["freezing_hazard"]+'%';
             }
         detailday+='</p></div>';
		}
	}
	
	
	
	
	$('#detail').html(detailday);
	$('#weather').toggle("slide");
	//console.log(el.find('#plugin_container'));
	el.find('#plugin_container').css('background','url('
                         + el.imagesPath
                         + 'background2.png) 50% 25px no-repeat');
	$('#detail').toggle("slide");
}


}
)(jQuery); //fin function($)
